@@ -12,19 +12,18 @@ use warnings;
 
 use base 'Catalyst::Action';
 use Class::Inspector;
-use Catalyst;
 use Catalyst::Request::REST;
 use Catalyst::Controller::REST;
 
 BEGIN { require 5.008001; }
 
-our $VERSION = '0.73';
+our $VERSION = '0.74';
 
 sub new {
   my $class  = shift;
   my $config = shift;
   Catalyst::Request::REST->_insert_self_into( $config->{class} );
-  return $class->SUPER::new($config, @_);
+  return $class->next::method($config, @_);
 }
 
 =head1 NAME
@@ -37,11 +36,11 @@ Catalyst::Action::REST - Automated REST Method Dispatching
       ... do setup for HTTP method specific handlers ...
     }
 
-    sub foo_GET { 
+    sub foo_GET {
       ... do something for GET requests ...
     }
 
-    sub foo_PUT { 
+    sub foo_PUT {
       ... do somethign for PUT requests ...
     }
 
@@ -49,13 +48,13 @@ Catalyst::Action::REST - Automated REST Method Dispatching
 
 This Action handles doing automatic method dispatching for REST requests.  It
 takes a normal Catalyst action, and changes the dispatch to append an
-underscore and method name. 
+underscore and method name.
 
 For example, in the synopsis above, calling GET on "/foo" would result in
 the foo_GET method being dispatched.
 
-If a method is requested that is not implemented, this action will 
-return a status 405 (Method Not Found).  It will populate the "Allow" header 
+If a method is requested that is not implemented, this action will
+return a status 405 (Method Not Found).  It will populate the "Allow" header
 with the list of implemented request methods.  You can override this behavior
 by implementing a custom 405 handler like so:
 
@@ -90,59 +89,71 @@ sub dispatch {
     my $c    = shift;
 
     my $controller = $c->component( $self->class );
-    my $method     = $self->name . "_" . uc( $c->request->method );
-    if ( $controller->can($method) ) {
+    my $rest_method = $self->name . "_" . uc( $c->request->method );
+
+    my ($code, $name);
+
+    # Common case, for foo_GET etc
+    if ($code = $controller->can($rest_method)) {
+        # Exceute normal action
         $c->execute( $self->class, $self, @{ $c->req->args } );
-        return $controller->$method( $c, @{ $c->req->args } );
-    } else {
-        if ( $c->request->method eq "OPTIONS" ) {
-            return $self->_return_options($c);
-        } else {
-            my $handle_ni = $self->name . "_not_implemented";
-            if ( $controller->can($handle_ni) ) {
-                return $controller->$handle_ni( $c, @{ $c->req->args } );
-            } else {
-                return $self->_return_not_implemented($c);
-            }
-        }
+        $name = $rest_method;
     }
-}
 
-sub _return_options {
-    my ( $self, $c ) = @_;
+    # Generic handling for foo_OPTIONS
+    if (!$code && $c->request->method eq "OPTIONS") {
+        $name = $rest_method;
+        $code = sub { $self->_return_options($self->name, @_) };
+    }
 
-    my @allowed = $self->_get_allowed_methods($c);
-    $c->response->content_type('text/plain');
-    $c->response->status(200);
-    $c->response->header( 'Allow' => \@allowed );
+    # Otherwise, not implemented.
+    if (!$code) {
+        $name = $self->name . "_not_implemented";
+        $code = $controller->can($name) # User method
+            # Generic not implemented
+            || sub { $self->_return_not_implemented($self->name, @_) };
+    }
+
+    # localise stuff so we can dispatch the action 'as normal, but get
+    # different stats shown, and different code run.
+    local $self->{code} = $code;
+    local $self->{reverse} = $name;
+
+    $c->execute( $self->class, $self, @{ $c->req->args } );
 }
 
 sub _get_allowed_methods {
-    my ( $self, $c ) = @_;
-
-    my $controller = $self->class;
-    my $methods    = Class::Inspector->methods($controller);
+    my ( $self, $controller, $c, $name ) = @_;
+    my $class = ref($controller) ? ref($controller) : $controller;
+    my $methods    = Class::Inspector->methods($class);
     my @allowed;
     foreach my $method ( @{$methods} ) {
-        my $name = $self->name;
         if ( $method =~ /^$name\_(.+)$/ ) {
             push( @allowed, $1 );
         }
     }
     return @allowed;
+};
+
+sub _return_options {
+    my ( $self, $method_name, $controller, $c) = @_;
+    my @allowed = $self->_get_allowed_methods($controller, $c, $method_name);
+    $c->response->content_type('text/plain');
+    $c->response->status(200);
+    $c->response->header( 'Allow' => \@allowed );
 }
 
 sub _return_not_implemented {
-    my ( $self, $c ) = @_;
+    my ( $self, $method_name, $controller, $c ) = @_;
 
-    my @allowed = $self->_get_allowed_methods($c);
+    my @allowed = $self->_get_allowed_methods($controller, $c, $method_name);
     $c->response->content_type('text/plain');
     $c->response->status(405);
     $c->response->header( 'Allow' => \@allowed );
     $c->response->body( "Method "
           . $c->request->method
           . " not implemented for "
-          . $c->uri_for( $self->reverse ) );
+          . $c->uri_for( $method_name ) );
 }
 
 1;
@@ -162,23 +173,16 @@ L<Catalyst::Action::Serialize>, L<Catalyst::Action::Deserialize>
 
 =item Q: I'm getting a "415 Unsupported Media Type" error. What gives?!
 
-A:  Most likely, you haven't set Content-type equal to "application/json", or one of the 
-accepted return formats.  You can do this by setting it in your query string thusly:
-?content-type=application%2Fjson (where %2F == / uri escaped). 
+A:  Most likely, you haven't set Content-type equal to "application/json", or
+one of the accepted return formats.  You can do this by setting it in your query
+accepted return formats.  You can do this by setting it in your query string
+thusly: C<< ?content-type=application%2Fjson (where %2F == / uri escaped). >>
 
-**NOTE** Apache will refuse %2F unless configured otherise.
-Make sure AllowEncodedSlashes On is in your httpd.conf file in order for this to run smoothly.
+B<NOTE> Apache will refuse %2F unless configured otherise.
+Make sure C<< AllowEncodedSlashes On >> is in your httpd.conf file in orde
+for this to run smoothly.
 
-=cut
-
-=cut
-
-
-
-
-=head1 MAINTAINER
-
-J. Shirley <jshirley@gmail.com>
+=back
 
 =head1 CONTRIBUTORS
 
@@ -190,11 +194,17 @@ John Goulah
 
 Daisuke Maki <daisuke@endeworks.jp>
 
+J. Shirley <jshirley@gmail.com>
+
+Hans Dieter Pearcey
+
+Tomas Doran (t0m) <bobtfish@bobtfish.net>
+
 =head1 AUTHOR
 
 Adam Jacob <adam@stalecoffee.org>, with lots of help from mst and jrockway
 
-Marchex, Inc. paid me while I developed this module.  (http://www.marchex.com)
+Marchex, Inc. paid me while I developed this module. (L<http://www.marchex.com>)
 
 =head1 LICENSE
 
